Class AbstractApplicationMetadata

    • Constructor Detail

      • AbstractApplicationMetadata

        protected AbstractApplicationMetadata()
    • Method Detail

      • getMetadata

        protected abstract Optional<String> getMetadata()
        Returns the meta data as a String that shall be used to build up the complete Project meta data. If no metadata exists, returns an empty optional.
        Returns:
        the meta data or empty if none exists for this session