Class AbstractApplicationMetadata
- java.lang.Object
-
- com.speedment.runtime.application.AbstractApplicationMetadata
-
- All Implemented Interfaces:
ApplicationMetadata
- Direct Known Subclasses:
EmptyApplicationMetadata
public abstract class AbstractApplicationMetadata extends Object implements ApplicationMetadata
- Since:
- 3.0.0
- Author:
- Emil Forslund
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedAbstractApplicationMetadata()
-
Method Summary
All Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description protected abstract Optional<String>getMetadata()Returns the meta data as a String that shall be used to build up the complete Project meta data.com.speedment.runtime.config.ProjectmakeProject()
-
-
-
Method Detail
-
getMetadata
protected abstract Optional<String> getMetadata()
Returns the meta data as a String that shall be used to build up the complete Project meta data. If no metadata exists, returns an empty optional.- Returns:
- the meta data or empty if none exists for this session
-
makeProject
public com.speedment.runtime.config.Project makeProject()
- Specified by:
makeProjectin interfaceApplicationMetadata
-
-